@@ -86,7 +86,17 @@ def rotate_func(args):
     """
     labels, coords = xyz_py.load_xyz(args.xyz_file)
 
-    xyz_py.rotate_coords(coords, args.alpha, args.beta, args.gamma)
+    if args.radians:
+        xyz_py.rotate_coords(
+            coords, args.alpha, args.beta, args.gamma
+        )
+    else:
+        xyz_py.rotate_coords(
+            coords,
+            args.alpha*180./np.pi,
+            args.beta*180./np.pi,
+            args.gamma*180./np.pi
+        )
 
     if args.out_f_name:
         out_f_name = args.out_f_name
@@ -171,13 +181,13 @@ def read_args(arg_list=None):
 
     """
 
-    description = '''
+    description = """
     A package for manipulating xyz files and chemical structures
-    '''
+    """
 
-    epilog = '''
+    epilog = """
     To display options for a specific program, use xyz_py PROGRAMNAME -h
-    '''
+    """
 
     parser = argparse.ArgumentParser(
         description=description,
@@ -185,25 +195,25 @@ def read_args(arg_list=None):
         formatter_class=argparse.RawDescriptionHelpFormatter
     )
 
-    subparsers = parser.add_subparsers(dest='prog')
+    subparsers = parser.add_subparsers(dest="prog")
 
     struct_info = subparsers.add_parser(
-        'struct_info',
+        "struct_info",
         description="Extracts structural information (bonds, angles and \
                      dihedrals) from xyz file"
     )
     struct_info.set_defaults(func=struct_info_func)
 
     struct_info.add_argument(
-        'xyz_file',
+        "xyz_file",
         type=str,
-        help='File containing xyz coordinates in .xyz format'
+        help="File containing xyz coordinates in .xyz format"
     )
 
     struct_info.add_argument(
         "--cutoffs",
         type=str,
-        nargs='+',
+        nargs="+",
         default=[],
         metavar=["symbol", "cutoff"],
         help="Change cutoff for symbol to cutoff e.g. Gd 2.5"
@@ -218,62 +228,68 @@ def read_args(arg_list=None):
     )
 
     rotate = subparsers.add_parser(
-        'rotate',
-        description="Rotate xyz file by alpha, beta, gamma in radians using \
+        "rotate",
+        description="Rotate xyz file by alpha, beta, gamma in degrees using \
                      Easyspin convention"
     )
     rotate.set_defaults(func=rotate_func)
 
     rotate.add_argument(
-        'xyz_file',
+        "xyz_file",
         type=str,
-        help='File containing xyz coordinates in .xyz format'
+        help="File containing xyz coordinates in .xyz format"
     )
 
     rotate.add_argument(
-        'alpha',
+        "alpha",
         type=float,
-        help='Alpha angle in radians'
+        help="Alpha angle in degrees"
     )
 
     rotate.add_argument(
-        'beta',
+        "beta",
         type=float,
-        help='Beta angle in radians'
+        help="Beta angle in degrees"
     )
 
     rotate.add_argument(
-        'gamma',
+        "gamma",
         type=float,
-        help='Gamma angle in radians'
+        help="Gamma angle in degrees"
     )
 
     rotate.add_argument(
-        '--out_f_name',
+        "-r", "--radians",
+        action="store_true",
+        help="Use radians instead of degrees"
+    )
+
+    rotate.add_argument(
+        "--out_f_name",
         type=str,
         metavar="file_name",
-        help='Output file name - default is append xyz file with _rotated'
+        help="Output file name - default is append xyz file with _rotated"
     )
 
     list_form = subparsers.add_parser(
-        'list_formulae',
+        "list_formulae",
         description="Finds bonded entities in xyz file using adjacency, and \
                      prints their formula and number of ocurrences"
     )
     list_form.set_defaults(func=list_form_func)
 
     list_form.add_argument(
-        'xyz_file',
+        "xyz_file",
         type=str,
-        help='File containing xyz coordinates in .xyz format'
+        help="File containing xyz coordinates in .xyz format"
     )
 
     list_form.add_argument(
-        '--cutoffs',
+        "--cutoffs",
         type=str,
         nargs="+",
         metavar="symbol number",
-        help='Modify cutoff used to define bonds'
+        help="Modify cutoff used to define bonds"
     )
 
     # If arg_list==None, i.e. normal cli usage, parse_args() reads from
