@@ -151,10 +151,11 @@ def load_xyz(f_name: str, atomic_numbers: bool = False,
     """
 
     if atomic_numbers:
-        _numbers = list(np.loadtxt(f_name, skiprows=2, usecols=0, dtype=int))
-        _labels = num_to_lab(_numbers)
+        _numbers = np.loadtxt(f_name, skiprows=2, usecols=0, dtype=int)
+        _labels = num_to_lab(_numbers.tolist())
     else:
-        _labels = list(np.loadtxt(f_name, skiprows=2, usecols=0, dtype=str))
+        _labels = np.loadtxt(f_name, skiprows=2, usecols=0, dtype=str)
+        _labels = _labels.tolist()
 
     # Set labels as capitals
     _labels = [lab.capitalize() for lab in _labels]
@@ -1035,13 +1036,39 @@ def find_entities(labels, coords, adjust_cutoff={}):
     """
 
     # Remove label numbers if present
-    _labels = remove_numbers(labels)
+    labels_nn = remove_numbers(labels)
 
     # Generate adjacency matrix using ASE
-    adjacency = get_adjacency(_labels, coords, adjust_cutoff=adjust_cutoff)
+    adjacency = get_adjacency(labels_nn, coords, adjust_cutoff=adjust_cutoff)
+
+    # Find entities
+    mol_indices = find_entities_from_adjacency(labels_nn, adjacency)
+
+    return mol_indices
+
+
+def find_entities_from_adjacency(labels_nn, adjacency):
+    """
+    Finds formulae of entities given in labels and adjacency matrix
+
+    Parameters
+    ----------
+    labels : list
+        atomic labels
+    adjacency : np.ndarray
+        Adjacency matrix (0,1) with same order as labels
+
+    Returns
+    -------
+    dict
+        keys = molecular formula,
+        vals = list of lists, where each list contains the indices of a single
+                occurrence of the `key`, and the indices match the order given
+                in `labels` and `coords`
+    """
 
     # Count number of atoms
-    n_atoms = len(labels)
+    n_atoms = len(labels_nn)
 
     # Set current fragment as start atom
     curr_frag = {0}
@@ -1071,7 +1098,7 @@ def find_entities(labels, coords, adjust_cutoff={}):
         if prev_frag == curr_frag:
 
             # Generate molecular formula of current fragment
-            curr_labels = [_labels[it] for it in curr_frag]
+            curr_labels = [labels_nn[it] for it in curr_frag]
             curr_formula = count_elements(curr_labels)
 
             mol_indices[formdict_to_formstr(curr_formula)].append(
@@ -1084,60 +1111,9 @@ def find_entities(labels, coords, adjust_cutoff={}):
             # Reset lists of labels and indices ready for next cycle
             curr_frag = {min(unvisited)} if unvisited else curr_frag
 
-    return dict(mol_indices)
+    mol_indices = dict(mol_indices)
 
-
-def remove_broken(labels, coords, formulae, adjust_cutoff={}, verbose=False,
-                  save=False, frag_f_name="fragments.xyz",
-                  clean_f_name="clean.xyz", mask=[], skip=[]):
-    """
-    Deprecated, use find_entities instead.
-
-    Parameters
-    ----------
-    labels : list
-        list of atomic labels
-    coords : np.ndarray
-        xyz coordinates as (n_atoms, 3) array
-    formulae : list
-        list of chemical formulae stored as dictionaries with atomic
-        symbol (key) count (val) pairs
-    adjust_cutoff : dict, optional
-        dictionary of atoms (keys) and new cutoffs (values)
-    verbose : bool, optional
-        print molecule count to screen
-    save : bool, optional
-        Save molecules and incomplete fragments to separate xyz files
-    frag_f_name : str, optional
-        Name for xyz file containing fragmented structures
-    clean_f_name : str, optional
-        Name for xyz file containing full molecules
-    mask : list, optional
-        list of 0 (exclude) and 1 (include) for each element
-            - if used, final lists will exclude masked elements
-    skip : list, optional
-        List of atomic indices which shall not be visited when tracing
-        bonding network
-
-    Returns
-    -------
-    list
-        atomic labels for full molecules
-    np.ndarray
-        xyz coordinates as (n_atoms, 3) array for full molecules
-    list
-        atomic labels for fragments
-    np.ndarray
-        xyz coordinates as (n_atoms, 3) array for fragments
-    dict
-        keys = molecular formula,
-        vals = list of lists of atomic indices
-                for each atom
-    """
-
-    print("xyz_py: remove_broken is deprecated, use find_entities instead")
-    exit()
-    return
+    return mol_indices
 
 
 def _calculate_rmsd(coords_1, coords_2):
